<%--<?xml version="1.0" encoding="ISO-8859-1" ?>--%>
<%--<%@ page language="java" contentType="text/html; charset=ISO-8859-1" pageEncoding="ISO-8859-1"%>--%>

<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
<%@ taglib uri="http://java.sun.com/jsp/jstl/functions" prefix="fn" %>
<%@ taglib uri="http://java.sun.com/jsp/jstl/fmt" prefix="fmt" %>
<%@ taglib uri="http://displaytag.sf.net" prefix="dt" %>


<c:import url="template_header.jsp" >
    <c:param name="title">Documentation</c:param>
</c:import>

<ol class="breadcrumb">
    <li><a href="${pageContext.request.contextPath}/index.jsp">Home</a></li>
    <li><a href="man_docs.jsp">Documentation</a></li>
    <li class="active"><a href="man_server_dev.jsp">Develop JABAWS</a></li>
</ol>
<div class="row">
    <div class="col-md-12">
        <div class="panel panel-default">
            <div class="panel panel-heading">
                <h1 class="panel-title">Command Line Client</h1>
            </div>
            <div class="panel-body">
                <!--<h4>About</h4>-->
                <ul>
                    <li><a href="#usingcclient1">Overview of the Command Line Client</a></li>
                    <li><a href="#usingcclient2">Command Line Client Usage</a></li>
                    <li><a href="#usingcclient3">Example Usage</a></li>
                </ul>
                <!--<p class="justify">-->
                <!--</p>-->
            </div>
        </div>
    </div>
</div>
<div class="row" id="usingcclient1">
    <div class="col-md-12">
        <div class="panel panel-default">
            <div class="panel panel-heading">
                <h1 class="panel-title">Overview of the Command Line Client</h1>
            </div>
            <div class="panel-body">
                <p class="justify">
                    The command line client comes as a part of
                    <a href="${pageContext.request.contextPath}/download.jsp#client">client package</a>
                    which you are welcome to download.
                    The command line client can be used to align sequences using any of JABAWS supported web
                    services. The client is OS independent and supports most of
                    the functions which can be accessed programmatically via
                    <a href="${pageContext.request.contextPath}/full_javadoc/">JABAWS API</a>. Using this client you could align sequences
                    using presets or custom parameters, please see examples of this below. Here is the
                    list of options supported by the command line client.
                </p>
            </div>
        </div>
    </div>
</div>
<div class="row" id="usingcclient2">
    <div class="col-md-12">
        <div class="panel panel-default">
            <div class="panel panel-heading">
                <h1 class="panel-title">Command Line Client Usage</h1>
            </div>
            <div class="panel-body">
                <pre><code class="bash">java -jar jaba-client.jar</code></pre>
                <pre><strong>Usage:</strong>
java -jar &lt;path_to_jar_file&gt; -h=host_and_context -s=serviceName ACTION [OPTIONS]
-h=&lt;host_and_context&gt; - a full URL to the JABAWS web server including context path e.g. http://10.31.10.159:8080/ws
-s=&lt;ServiceName&gt; - one of [MafftWS, MuscleWS, ClustalWS, ClustalOWS, TcoffeeWS, ProbconsWS, AAConWS, JronnWS, DisemblWS, GlobPlotWS, IUPredWS]
<br/>
<strong>ACTIONS:</strong>
-i=&lt;inputFile&gt; - full path to fasta formatted sequence file, from which to align sequences
-parameters - lists parameters supported by web service
-presets - lists presets supported by web service
-limits - lists web services limits
Please note that if input file is specified other actions are ignored
<br/>
<strong> OPTIONS:</strong> (only for use with -i action):
-r=&lt;presetName&gt; - name of the preset to use
-o=&lt;outputFile&gt; - full path to the file where to write an alignment
-f=&lt;parameterInputFile&gt; - the name of the file with the list of parameters to use.<br />
Please note that -r and -f options cannot be used together. Alignment is done with either preset or aparameters from the file, but not both!</pre>
            </div>
        </div>
    </div>
</div>
<div class="row" id="usingcclient3">
    <div class="col-md-12">
        <div class="panel panel-default">
            <div class="panel panel-heading">
                <h1 class="panel-title">Example Usage</h1>
            </div>
            <div class="panel-body">
                <p class="justify">
                    Align sequences from input.fasta file using Mafft web
                    service with default settings, print alignment in Clustal format to console.
                </p>
                <pre><code class="bash">java -jar jabaws-min-client.jar -h=http://myhost.compbio.ac.uk:8080/jabaws -s=MafftWS -i=d:\input.fasta</code></pre>
                <p class="justify">
                    Content of input.fasta file is show below (please note sequences has been
                    trimmed for clarity)
                </p>
                <pre>&gt;Foobar
MTADGPRELLQLRAAVRHRPQDFVAWL
&gt;Bar
MGDTTAGEMAVQRGLALHQ
&gt;Foofriend
MTADGPRELLQLRAAV</pre>
                <p class="justify">
                    Align as in above example, but write output alignment in a
                    file out.clustal, using parameters defined in prm.in file
                </p>
                <pre><code class="bash">java -jar jabaws-min-client.jar -h=http://myhost.compbio.ac.uk:8080/jabaws  -s=MafftWS -i=d:\input.fasta -o=d:\out.clustal -f=prm.in</code></pre>
                <p class="justify">
                    The content of the prm.in file is shown below
                <pre><code class="bash">--nofft
--noscore
--fastaparttree
--retree=10
--op=2.2</code></pre>
                <p class="justify">
                    The format of the file is the same for all JABAWS web services.
                    Parameters are specified in exactly the same way as for native
                    executables - alignment programs like Mafft etc. So parameters
                    which you can use with command line version of an alignment program
                    can be used with JABAWS. Most of the settings controlling alignment
                    process are supported, but because any output has to be handled by
                    JABAWS, settings controlling output are not allowed to be changed.
                    For a list of parameters supported by a web service see the next example.
                    In <em2>prm.in</em2> parameters are separated by the new line, and
                    name of the parameter is separated from its value with an equals
                    sign. This format is constant no matter which JABAWS web service is used.
                </p>
                <pre><code class="bash">java -jar jabaws-min-client.jar -h=http://myhost.compbio.ac.uk:8080/jabaws -s=MafftWS -parameters</code></pre>

                <p class="justify">
                    The same client can be used to access JABAWS on different hosts.
                    Just point the client to the host you want to use by changing the
                    value of -h key.
                </p>
                <p class="justify">
                    For example you used
                    <em2>-h=http://myhost.compbio.ac.uk:8080/jabaws</em2> server,
                    now you want to use another server to
                    <em2>-h=http://mylabserver.myuni.edu.</em2> This comes handy if
                    your favorite server is off and you need to do the job yesterday.
                </p>
            </div>
        </div>
    </div>
</div>

<jsp:include page="template_footer.jsp" />